@@ -3,13 +3,9 @@
 #ifndef EB_H
 #define EB_H 1
 
-/* Define _GNU_SOURCE on Linux, so we don't have an implicit declaration
- * of asprintf, but only if we are not compiling C++.
- * Turns out that when compiling C++ on LInux, _GNU_SOURCE is helpfully
- * predefined, so defining it twice generates a nasty warning.
- */
-
-#if defined(EDBROWSE_ON_LINUX) && !defined(__cplusplus)
+// Define _GNU_SOURCE on Linux, so we don't have an implicit declaration
+// of asprintf and strcasestr.
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 
@@ -51,7 +47,7 @@ typedef unsigned short ushort;
 typedef unsigned char uchar;
 
 /* We use unsigned char for boolean fields. */
-#ifndef __cplusplus
+#if !defined(__cplusplus) && __STDC_VERSION__ < 202311L
 typedef uchar bool;
 #define false 0
 #define true 1
@@ -98,10 +94,10 @@ We never want this to be true in the context of edbrowse.
 *********************************************************************/
 
 #define isspaceByte(c) (isspace((uchar)(c)) && !((c)&0x80))
-#define isalphaByte(c) isalpha((uchar)(c))
-#define isalnumByte(c) isalnum((uchar)(c))
-#define islowerByte(c) islower((uchar)(c))
-#define isupperByte(c) isupper((uchar)(c))
+#define isalphaByte(c) (isalpha((uchar)(c)) && !(c&0x80))
+#define isalnumByte(c) (isalnum((uchar)(c)) && !(c&0x80))
+#define islowerByte(c) (islower((uchar)(c)) && !(c&0x80))
+#define isupperByte(c) (isupper((uchar)(c)) && !(c&0x80))
 #define isdigitByte(c) isdigit((uchar)(c))
 #define ispunctByte(c) ispunct((uchar)(c))
 #define isprintByte(c) isprint((uchar)(c))
@@ -344,7 +340,7 @@ extern char lsformat[12];
 extern bool dno; // directory names only
 extern bool ebvar; // update environment variables before each shell command
 extern bool flow; // send mail with format=flowed
-extern bool caseInsensitive, searchStringsAll, searchWrap, ebre;
+extern bool caseInsensitive, searchStringsAll, searchSameMode, searchWrap, ebre;
 extern bool allowRedirection;	/* from http code 301, or http refresh */
 extern bool sendReferrer;	/* in the http header */
 extern bool allowJS;		// javascript on
