@@ -19,6 +19,7 @@ pst fetchLine(int n, int show);
 void displayLine(int n);
 void printDot(void);
 void printPrompt(void);
+void passToJdb(char *s);
 void initializeReadline(void);
 pst inputLine(const bool textEntry);
 void saveSubstitutionStrings(void);
@@ -37,6 +38,7 @@ void addTextToBackend(const char *inbuf);
 void delText(int start, int end) ;
 bool readFileArgv(const char *filename, int fromframe, const char *orig_head);
 bool writeFile(const char *name, int mode);
+void eb_variables(void);
 Tag *line2frame(int ln);
 bool jump2anchor(const Tag *jumptag, const char *newhash);
 bool runCommand(const char *line);
@@ -138,6 +140,7 @@ void setError(int msg, ...); //? use these only in the foreground!
 void showError(void);
 void showErrorConditional(char cmd);
 void showErrorAbort(void);
+void eb_printf(const char *fmt, ...);
 void eb_puts(const char *s);
 bool helpUtility(void);
 bool varCommand(const char *line);
@@ -281,6 +284,7 @@ void stringAndString(char **s, int *l, const char *t) ;
 void stringAndBytes(char **s, int *l, const char *t, int cnt) ;
 void stringAndChar(char **s, int *l, char c) ;
 void stringAndNum(char **s, int *l, int n) ;
+void stringAndLongLong(char **s, int *l, long long n) ;
 #define stringAndMessage(s, l, m) stringAndString(s, l, i_message(m))
 char *cloneString(const char *s) ;
 char *cloneMemory(const char *s, int n) ;
@@ -327,13 +331,14 @@ long long bufferSize(int cx, bool browsing);
 bool unfoldBufferW(const struct ebWindow *w, bool cr, char **data, int *len);
 bool unfoldBuffer(int cx, bool cr, char **data, int *len);
 void caseShift(char *s, char action) ;
+void i_caseShift(char *s, char action) ;
 void camelCase(char *s);
 char fileTypeByName(const char *name, int showlink) ;
 char fileTypeByHandle(int fd) ;
 off_t fileSizeByName(const char *name) ;
 off_t fileSizeByHandle(int fd) ;
 time_t fileTimeByName(const char *name) ;
-char *conciseSize(size_t n); //?
+char *conciseSize(long long n); //?
 char *conciseTime(time_t t); //?
 bool lsattrChars(const char *buf, char *dest);
 char *lsattr(const char *path, const char *flags); //?
