@@ -21,6 +21,7 @@ I can only hope this doesn't screw up some embedded javascript.
 void prepareForBrowse(char *h, int h_len)
 {
 	int i, j;
+	bool ab = false;
 
 	for (i = j = 0; i < h_len; ++i) {
 		if (h[i] == 0)
@@ -30,11 +31,14 @@ void prepareForBrowse(char *h, int h_len)
 				--j;
 			continue;
 		}
-		if (h[i] == InternalCodeChar)
+		if (h[i] == InternalCodeChar) {
 			h[i] = InternalCodeCharAlternate;
+			ab = true;
+		}
 		h[j++] = h[i];
 	}
 	h[j] = 0;		/* now it's a string */
+	if(ab) debugPrint(1, "changing ^b to ^a");
 
 /* undos the file */
 	for (i = j = 0; h[i]; ++i) {
@@ -48,13 +52,15 @@ void prepareForBrowse(char *h, int h_len)
 /* An input field cannot contain cr, lf, null, or the InternalCodeChar */
 void prepareForField(char *h)
 {
+	bool ab = false;
 	while (*h) {
 // this line is goofy cause null would terminate the loop
 		if (*h == 0) *h = ' ';
 		if (*h == '\n') *h = '\07'; // should never happen
-		if (*h == InternalCodeChar) *h = InternalCodeCharAlternate;
+		if (*h == InternalCodeChar) { *h = InternalCodeCharAlternate; ab = true; }
 		++h;
 	}
+	if(ab) debugPrint(1, "changing ^b to ^a");
 }
 
 /*********************************************************************
@@ -3278,6 +3284,19 @@ void showErrorAbort(void)
 	ebClose(99);
 }
 
+void eb_printf(const char *fmt, ...)
+{
+	va_list p;
+	va_start(p, fmt);
+	vprintf(fmt, p);
+	va_end(p);
+	if (debugFile) {
+		va_start(p, fmt);
+		vfprintf(debugFile, fmt, p);
+		va_end(p);
+	}
+}
+
 void eb_puts(const char *s)
 {
 	puts(s);
@@ -3435,19 +3454,24 @@ syntax:
 		l1 += 2;
 		goto top;
 	}
-	while(isalnum(*l3)) ++l3;
+	while(isalnum(*l3) || *l3 == '_') ++l3;
 	cut = *l3;
 	if(!cut) goto syntax;
 	if(!strchr(")+-*/", cut)) goto syntax;
 	t = (char*)l3, *t = 0;
-	if(*l2 == ':') value = getenv(lv);
+	if(*l2 == ':') eb_variables(), value = getenv(lv);
 	else value = varLookup(lv);
 	if(!value) {
 reference:
+#if 0
 		nzFree(ns);
 		setError(MSG_NoEbVar, lv);
 		*t = cut;
 		return false;
+#else
+		*t = cut;
+		goto syntax;
+#endif
 	}
 
 	if(cut == ')') { // simple variable reference
@@ -3489,7 +3513,7 @@ nextarg:
 	if(!strchr(")+-*/", cut)) goto syntax;
 	t = (char*)l3, *t = 0;
 	if(isalpha(*lv)) {
-		if(*l2 == ':') value = getenv(lv);
+		if(*l2 == ':') eb_variables(), value = getenv(lv);
 		else value = varLookup(lv);
 		if(!value) goto reference;
 		sign = 1;
