@@ -57,7 +57,7 @@ void eb_curl_global_init(void)
 	const unsigned int least_acceptable_version =
 	    (major << 16) | (minor << 8) | patch;
 	curl_version_info_data *version_data = NULL;
-
+	curlActive = true;
 	CURLcode curl_init_status = curl_global_init(CURL_GLOBAL_ALL);
 	if (curl_init_status != 0) goto libcurl_init_fail;
 	version_data = curl_version_info(CURLVERSION_NOW);
@@ -98,7 +98,6 @@ void eb_curl_global_init(void)
 	    curl_easy_setopt(global_http_handle, CURLOPT_SHARE,
 			     global_share_handle);
 	if (curl_init_status != CURLE_OK) goto libcurl_init_fail;
-	curlActive = true;
 	return;
 
 libcurl_init_fail:
@@ -1102,7 +1101,12 @@ perform:
 			g->buffer = initString(&g->length);
 			g->headers = initString(&g->headers_len);
 			g->code = 200;
-			curlret = (head_request ? CURLE_OK : CURLE_COULDNT_CONNECT);
+			if(head_request) {
+				curlret = CURLE_OK;
+			} else {
+				curlret = CURLE_COULDNT_CONNECT;
+				i_puts(MSG_NotInCache);
+			}
 		} else {
 			curlret = fetch_internet(g);
 		}
@@ -1625,12 +1629,13 @@ static void ftp_ls_line(struct i_get *g, char *line)
 			break;
 
 	if (j == 10 && line[j] == ' ') {	/* long list */
-		int fsize, nlinks;
+		long long fsize;
+		int nlinks;
 		char user[42], group[42];
 		char month[8];
 		int day;
 		char *q, *t;
-		sscanf(line + j, " %d %40s %40s %d %3s %d",
+		sscanf(line + j, " %d %40s %40s %lld %3s %d",
 		       &nlinks, user, group, &fsize, month + 1, &day);
 		q = strchr(line, ':');
 		if (q) {
@@ -1673,7 +1678,7 @@ static void ftp_ls_line(struct i_get *g, char *line)
 			if (line[0] == 'd')
 				stringAndChar(&g->buffer, &g->length, '/');
 			stringAndString(&g->buffer, &g->length, ": ");
-			stringAndNum(&g->buffer, &g->length, fsize);
+			stringAndLongLong(&g->buffer, &g->length, fsize);
 			stringAndChar(&g->buffer, &g->length, '\n');
 			return;
 		}
@@ -1778,7 +1783,7 @@ static void gopher_ls_line(struct i_get *g, char *line)
 			stringAndString(&g->buffer, &g->length, "<a href=x");
 		else
 			stringAndString(&g->buffer, &g->length,
-					"<form method='get' action=x");
+					"<form action=x");
 		g->buffer[g->length - 1] = qc;
 
 		if (!strncmp(pathname, "URL:", 4)) {
@@ -1814,7 +1819,7 @@ static void gopher_ls_line(struct i_get *g, char *line)
 	if (host) {
 		if (first == '7')
 			stringAndString(&g->buffer, &g->length,
-					" <input type='text' /> <input type='submit' /></form>");
+					" <input type='text'> <input type='submit'></form>");
 		else
 			stringAndString(&g->buffer, &g->length, "</a>");
 	}
@@ -1902,7 +1907,7 @@ void ebcurl_setError(CURLcode curlret, const char *url, int action,
 
 	case CURLE_GOT_NOTHING:
 	case CURLE_RECV_ERROR:
-		(*fn) (MSG_WebRead);
+		(*fn) (MSG_WebRead, curl_error);
 		break;
 
 	case CURLE_SEND_ERROR:
@@ -2152,7 +2157,7 @@ Custom headers to upload to a different name, and then rename the local file.
 We don't need to do that either.
 *********************************************************************/
 
-	f = fopen(tempfile, (cw->binMode ? "rb" : "r"));
+	f = fopen(tempfile, (cw->binMode ? "rbe" : "re"));
 	if(!f) { // this should never happen
 		setError(MSG_NoOpen, tempfile, strerror(errno));
 		goto fail;
@@ -2842,8 +2847,9 @@ default_filename:
 		filepart = g->cdfn;
 	else
 		filepart = getFileURL(g->urlcopy, true);
-// transliterate to get rid of /
 	fp2 = cloneString(filepart);
+	unpercentURL(fp2);
+// transliterate to get rid of /
 	for (s = fp2; *s; ++s)
 		if (*s == '/' || *s == '\\')
 			*s = '_';
