@@ -12,7 +12,7 @@ Frame *cf;
 int gfsn; // global frame sequence number
 const char *progname;
 const char eol[] = "\r\n";
-const char *version = "3.8.10";
+const char *version = "3.8.12";
 char *changeFileName;
 char *configFile, *addressFile, *cookieFile, *emojiFile;
 char *mailDir, *mailUnread, *mailStash, *mailReply;
@@ -48,7 +48,7 @@ bool ismc, passMail, attimg;
 bool inInput, inInitFunction, listNA;
 char *dbarea, *dblogin, *dbpw;	// to log into the database
 bool fetchBlobColumns;
-bool caseInsensitive, searchStringsAll, searchWrap = true, ebre = true;
+bool caseInsensitive, searchStringsAll, searchSameMode, searchWrap = true, ebre = true;
 bool binaryDetect = true;
 bool inputReadLine;
 bool curlAuthNegotiate = false;
@@ -911,7 +911,7 @@ static int *argl_ptr;
 static int *rb_ln, *rb_ln2, *rb_b;
 
 struct ebSettings {
-	bool rl, endm, lna, H, ci, sg, su8, sw, ebre, bd, iu, hf, hr, vs, hlocal, sr, can, ftpa, bg, jsbg, js, showall, pg, fbc, ls_reverse, fllo, dno, ebvar, flow, attimg;
+	bool rl, endm, lna, H, ci, sg, su8, ss, sw, ebre, bd, iu, hf, hr, vs, hlocal, sr, can, ftpa, bg, jsbg, js, showall, pg, fbc, ls_reverse, fllo, dno, ebvar, flow, attimg;
 	uchar dw, ls_sort;
 	char lsformat[12], showProgress;
 	char *currentAgent;
@@ -943,6 +943,7 @@ static void saveEbSettings(struct ebSettings *s)
 	s->lna = listNA;
 	s->fbc = fetchBlobColumns;
 	s->ls_reverse = ls_reverse;
+	s->ss = searchSameMode;
 	s->sw = searchWrap;
 	s->ebre = ebre;
 	s->hr = allowRedirection;
@@ -986,6 +987,7 @@ static void restoreEbSettings(struct ebSettings *s)
 	curlAuthNegotiate = s->can;
 	listNA = s->lna;
 	ls_reverse = s->ls_reverse;
+	searchSameMode = s->ss;
 	searchWrap = s->sw;
 	ebre = s->ebre;
 	allowRedirection = s->hr;
@@ -1312,6 +1314,11 @@ bool runBuffer(int b, const Window *w, bool stopflag, int ln1, int ln2)
 			return false;
 		}
 		*s = 0;
+		if(cw->jdb_frame) {
+			passToJdb(p);
+			free(p);
+			continue;
+		}
 		rb_ln = &ln, rb_ln2 = &ln2, rb_b = &b, endl_ptr = 0;
 // Here we go!
 		debugPrint(3, "< %s", p);
@@ -1889,7 +1896,7 @@ inside:
 			ftype = fileTypeByName(v, 0);
 			if (ftype && ftype != 'f')
 				cfgAbort1(MSG_EBRC_JarNotFile, v);
-			j = open(v, O_WRONLY | O_APPEND | O_CREAT,
+			j = open(v, O_WRONLY | O_APPEND | O_CREAT | O_CLOEXEC,
 				 MODE_private);
 			if (j < 0)
 				cfgAbort1(MSG_EBRC_JarNoWrite, v);
@@ -1928,7 +1935,7 @@ inside:
 			ftype = fileTypeByName(v, 0);
 			if (ftype && ftype != 'f')
 				cfgAbort1(MSG_EBRC_SSLNoFile, v);
-			j = open(v, O_RDONLY);
+			j = open(v, O_RDONLY | O_CLOEXEC);
 			if (j < 0)
 				cfgAbort1(MSG_EBRC_SSLNoRead, v);
 			close(j);
@@ -2057,7 +2064,7 @@ inside:
 			ftype = fileTypeByName(v, 0);
 			if (ftype && ftype != 'f')
 				cfgAbort1(MSG_EBRC_KeyNoFile, v);
-			j = open(v, O_RDONLY);
+			j = open(v, O_RDONLY | O_CLOEXEC);
 			if (j < 0)
 				cfgAbort1(MSG_EBRC_KeyNoRead, v);
 			close(j);
@@ -2310,7 +2317,7 @@ const char *fetchReplace(const char *u)
 
 static void loadReplacements(void)
 {
-	FILE *f = fopen("jslocal", "r");
+	FILE *f = fopen("jslocal", "re");
 	struct JSR *j;
 	char *s;
 	int n = 0;
