@@ -490,7 +490,7 @@ enum {
 	MSG_NoTilde,
 	MSG_Submit,
 	MSG_FrameNotHTML,
-	MSG_Secure,
+	MSG_NotInCache,
 	MSG_Bymail,
 	MSG_Reset,
 	MSG_ShellExpand,
@@ -860,4 +860,6 @@ MSG_ImaskOn,
 	MSG_False,
 	MSG_RemovingBOM,
 	MSG_RestoringBOM,
+	MSG_SearchSameModeOff,
+	MSG_SearchSameModeOn,
 };
