@@ -267,6 +267,13 @@ void stringAndNum(char **s, int *l, int n)
 	stringAndString(s, l, a);
 }
 
+void stringAndLongLong(char **s, int *l, long long n)
+{
+	char a[32];
+	sprintf(a, "%lld", n);
+	stringAndString(s, l, a);
+}
+
 char *cloneString(const char *s)
 {
 	char *t;
@@ -650,7 +657,7 @@ void setDebugFile(const char *name)
 	if (!name || !*name)
 		return;
 	debugFileName = cloneString(name);
-	debugFile = fopen(name, "w");
+	debugFile = fopen(name, "we");
 	if (debugFile) {
 		setlinebuf(debugFile);
 	} else
@@ -813,7 +820,7 @@ int fileIntoMemory(const char *filename, char **data, int *len, bool inparts)
 		setError(MSG_RegularFile, filename);
 		return 0;
 	}
-	fh = open(filename, O_RDONLY | O_BINARY);
+	fh = open(filename, O_RDONLY | O_BINARY | O_CLOEXEC);
 	if (fh < 0) {
 		setError(MSG_NoOpen, filename, strerror(errno));
 		return 0;
@@ -831,7 +838,7 @@ fh_set:
 bool memoryOutToFile(const char *filename, const char *data, int len)
 {
 	int fh =
-	    open(filename, O_CREAT | O_TRUNC | O_WRONLY | O_BINARY, MODE_rw);
+	    open(filename, O_CREAT | O_TRUNC | O_WRONLY | O_BINARY | O_CLOEXEC, MODE_rw);
 	if (fh < 0) {
 			setError(MSG_TempNoCreate2, filename, strerror(errno));
 		return false;
@@ -940,14 +947,11 @@ bool unfoldBuffer(int cx, bool cr, char **data, int *len)
 	return unfoldBufferW(w, cr, data, len);
 }
 
-/* shift string to upper, lower, or mixed case */
-/* action is u, l, or m. */
+// shift string to upper or lower case
+// action is u or l.
 void caseShift(char *s, char action)
 {
 	char c;
-	int mc = 0;
-	bool ws = true;
-
 	for (; (c = *s); ++s) {
 		if (action == 'u') {
 			if (isalphaByte(c))
@@ -959,27 +963,91 @@ void caseShift(char *s, char action)
 				*s = tolower(c);
 			continue;
 		}
-/* mixed case left */
-		if (isalphaByte(c)) {
+	}
+}
+
+// support routines for i_caseShift below
+// this assumes a utf8 string
+static bool i_isalpha(const char *s)
+{
+	uchar c = *(const uchar*)s, d = *(const uchar*)(s+1);
+	if(!(c&0x80)) return isalpha(c) ? true : false;
+	if((c&0xe0) != 0xc0) return false;
+	uchar u = (c<<6) | (d&0x3f);
+	if(u < 0xc0) return false; // out of range
+	if(u == 0xd7 || u == 0xf7) return false; // times divide
+	return true;
+}
+
+static void i_tolower(char *s)
+{
+	uchar c = *(uchar*)s, d = *(uchar*)(s+1);
+	if(!(c&0x80)) {
+		*s = tolower(c);
+		return;
+	}
+	uchar u = (c<<6) | (d&0x3f);
+	if(u == 0xdf) return;
+	 s[1] |= 0x20;
+}
+
+static void i_toupper(char *s)
+{
+	uchar c = *(uchar*)s, d = *(uchar*)(s+1);
+	if(!(c&0x80)) {
+		*s = toupper(c);
+		return;
+	}
+	 s[1] &= ~0x20;
+}
+
+// shift string to upper, lower, or mixed case.
+// action is u, l, or m.
+// This is international version, up to unicode 0xff.
+void i_caseShift(char *s, char action)
+{
+	char c;
+	int mc = 0;
+	bool ws = true;
+	char *s0 = s;
+
+	for (; (c = *s); ++s) {
+// trailing parts of utf8
+	if(((uchar)c&0xc0) == 0x80) continue;
+		if (action == 'u') {
+			if (i_isalpha(s))
+				i_toupper(s);
+			continue;
+		}
+		if (action == 'l') {
+			if (i_isalpha(s))
+				i_tolower(s);
+			continue;
+		}
+// mixed case left
+		if (i_isalpha(s)) {
 			if (ws)
-				c = toupper(c);
+				i_toupper(s);
 			else
-				c = tolower(c);
-			if (ws && c == 'M')
-				mc = 1;
-			else if (mc == 1 && c == 'c')
-				mc = 2;
+				i_tolower(s);
+			if (ws && *s == 'M') mc = 1;
+			else if (mc == 1 && *s == 'c') mc = 2;
 			else if (mc == 2) {
-				c = toupper(c);
+				i_toupper(s);
 				mc = 0;
-			} else
-				mc = 0;
-			*s = c;
+			} else mc = 0;
 			ws = false;
 			continue;
 		}
 		ws = true, mc = 0;
-	}			/* loop */
+// code for don't and we'll etc
+		if((c == '\'' ||
+	(c == 0xe0 && s[1] == 0x80 && s[2] == 0x9d)) &&
+	s > s0 &&
+	!(s[-1]&0x80) &&
+	isalpha(s[-1]))
+		ws = false;
+	}
 }
 
 // foo-bar has to become fooBar
@@ -1107,34 +1175,42 @@ time_t fileTimeByName(const char *name)
 	return buf.st_mtime;
 }
 
-char *conciseSize(size_t n)
+char *conciseSize(long long n)
 {
 	static char buf[32];
-	unsigned long u, v;
-	if (n >= 1000000000) {
+	size_t u;
+	unsigned int v;
+	if (n >= 1000000000000) {
+		u = n/1000000000000;
+		v = n/100000000000 % 10;
+		if(u >= 10 || !v)
+			sprintf(buf, "%zuT", u);
+		else
+			sprintf(buf, "%zu.%0uT", u, v);
+	} else if (n >= 1000000000) {
 		u = n/1000000000;
 		v = n/100000000 % 10;
 		if(u >= 10 || !v)
-			sprintf(buf, "%luG", u);
+			sprintf(buf, "%zuG", u);
 		else
-			sprintf(buf, "%lu.%0luG", u, v);
+			sprintf(buf, "%zu.%0uG", u, v);
 	} else if (n >= 1000000) {
 		u = n/1000000;
 		v = n/100000 % 10;
 		if(u >= 10 || !v)
-			sprintf(buf, "%luM", u);
+			sprintf(buf, "%zuM", u);
 		else
-			sprintf(buf, "%lu.%0luM", u, v);
+			sprintf(buf, "%zu.%0uM", u, v);
 	} else if (n >= 1000) {
 		u = n/1000;
 		v = n/100 % 10;
 		if(u >= 10 || !v)
-			sprintf(buf, "%luK", u);
+			sprintf(buf, "%zuK", u);
 		else
-			sprintf(buf, "%lu.%0luK", u, v);
+			sprintf(buf, "%zu.%0uK", u, v);
 	} else {
-		u = n;
-		sprintf(buf, "%lu", u);
+		v = n;
+		sprintf(buf, "%u", v);
 	}
 	return buf;
 }
@@ -1559,6 +1635,7 @@ const char *nextScanFile(const char *base)
 	if (!df) {
 		if (!base)
 			base = ".";
+		// Seems safe to assume opendir will O_CLOEXEC under the hood.
 		df = opendir(base);
 /* directory could be unreadable */
 		if (!df) {
@@ -2461,7 +2538,7 @@ void appendFile(const char *fname, const char *message, ...)
 {
 	FILE *f;
 	va_list p;
-	f = efopen(fname, "a");
+	f = efopen(fname, "ae");
 	va_start(p, message);
 	vfprintf(f, message, p);
 	va_end(p);
@@ -2472,7 +2549,7 @@ void appendFile(const char *fname, const char *message, ...)
 /* like the above, but no formatting */
 void appendFileNF(const char *filename, const char *msg)
 {
-	FILE *f = efopen(filename, "a");
+	FILE *f = efopen(filename, "ae");
 	fprintf(f, "%s\n", msg);
 	fclose(f);
 }
